import { AbstractBatchOperation, AbstractLevel } from "abstract-level";
export type LevelBatchOptions = {
    interval: number;
    onError?: (error: any) => void;
};
export type LazyLevelOptions = {
    batch?: LevelBatchOptions;
};
export interface SimpleLevel {
    get status(): "opening" | "open" | "closing" | "closed";
    close(): Promise<void>;
    open(): Promise<void>;
    get(key: string): Promise<Uint8Array | undefined>;
    put(key: string, value: Uint8Array): any;
    del(key: any): Promise<void>;
}
export default class LazyLevel implements SimpleLevel {
    _store: AbstractLevel<any, any, any>;
    _interval: any;
    _txQueue?: AbstractBatchOperation<AbstractLevel<any, string, Uint8Array>, string, Uint8Array>[];
    _tempStore?: Map<string, Uint8Array>;
    _tempDeleted?: Set<string>;
    _txPromise?: Promise<void>;
    _opts?: LazyLevelOptions;
    constructor(store: AbstractLevel<any, any, any>, opts?: LazyLevelOptions | {
        batch: boolean;
    });
    get status(): "opening" | "open" | "closing" | "closed";
    idle(): Promise<void>;
    close(): Promise<void>;
    open(): Promise<void>;
    get(key: string): Promise<Uint8Array | undefined>;
    getByPrefix(prefix: string): Promise<Uint8Array[]>;
    deleteByPrefix(prefix: string): Promise<void>;
    set(key: string, value: Uint8Array): Promise<void> | undefined;
    put(key: string, value: Uint8Array): Promise<void> | undefined;
    del(key: string): Promise<void>;
    delAll(keys: string[]): Promise<void>;
    sublevel(name: string): LazyLevel;
}
